<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="el">
<context>
    <name>CardWidget</name>
    <message>
        <location filename="../../cardwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <location filename="../../cardwidget.ui" line="29"/>
        <source>Card Name</source>
        <translation>Όνομα κάρτας</translation>
    </message>
    <message>
        <location filename="../../cardwidget.ui" line="38"/>
        <source>Profile:</source>
        <translation>Ταυτότητα:</translation>
    </message>
    <message>
        <location filename="../../cardwidget.cc" line="66"/>
        <source>pa_context_set_card_profile_by_index() failed</source>
        <translation>το pa_context_set_card_profile_by_index() απέτυχε</translation>
    </message>
</context>
<context>
    <name>Channel</name>
    <message>
        <location filename="../../channel.cc" line="89"/>
        <source>%1% (%2dB)</source>
        <comment>volume slider label [X% (YdB)]</comment>
        <translation>%1% (%2dB)</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="93"/>
        <source>%1%</source>
        <comment>volume slider label [X%]</comment>
        <translation>%1%</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="160"/>
        <source>&lt;small&gt;Silence&lt;/small&gt;</source>
        <translation>&lt;small&gt;Σίγαση&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="160"/>
        <source>&lt;small&gt;Min&lt;/small&gt;</source>
        <translation>&lt;small&gt;Ελάχ&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="162"/>
        <source>&lt;small&gt;100% (0dB)&lt;/small&gt;</source>
        <translation>&lt;small&gt;100% (0dB)&lt;/small&gt;</translation>
    </message>
    <message>
        <location filename="../../channel.cc" line="165"/>
        <source>&lt;small&gt;&lt;i&gt;Base&lt;/i&gt;&lt;/small&gt;</source>
        <translation>&lt;small&gt;&lt;i&gt;Βάση&lt;/i&gt;&lt;/small&gt;</translation>
    </message>
</context>
<context>
    <name>DeviceWidget</name>
    <message>
        <location filename="../../devicewidget.ui" line="14"/>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="36"/>
        <source>Device Title</source>
        <translation>Τίτλος συσκευής</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="56"/>
        <source>Mute audio</source>
        <translation>Σίγαση ήχου</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="69"/>
        <source>Lock channels together</source>
        <translation>Κλείδωμα των καναλιών μαζί</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="85"/>
        <source>Set as fallback</source>
        <translation>Ορισμός ως συσκευή μετάπτωσης</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="103"/>
        <source>&lt;b&gt;Port:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Θύρα:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="126"/>
        <source>Show advanced options</source>
        <translation>Προβολή προηγμένων επιλογών</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="172"/>
        <source>PCM</source>
        <translation>PCM</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="182"/>
        <source>AC3</source>
        <translation>AC3</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="189"/>
        <source>EAC3</source>
        <translation>EAC3</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="196"/>
        <source>DTS</source>
        <translation>DTS</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="203"/>
        <source>MPEG</source>
        <translation>MPEG</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="210"/>
        <source>AAC</source>
        <translation>AAC</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="238"/>
        <source>&lt;b&gt;Latency offset:&lt;/b&gt;</source>
        <translation>&lt;b&gt;Μετατόπιση του λανθάνοντος χρόνου:&lt;/b&gt;</translation>
    </message>
    <message>
        <location filename="../../devicewidget.ui" line="245"/>
        <source> ms</source>
        <translation> ms</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="40"/>
        <source>Rename device...</source>
        <translation>Μετονομασία συσκευής...</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="154"/>
        <source>pa_context_set_port_latency_offset() failed</source>
        <translation>το pa_context_set_port_latency_offset() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="225"/>
        <source>Sorry, but device renaming is not supported.</source>
        <translation>Λυπάμαι, αλλά η μετονομασία της συσκευής δεν υποστηρίζεται.</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="226"/>
        <source>You need to load module-device-manager in the PulseAudio server in order to rename devices</source>
        <translation>Πρέπει να φορτώσετε το module-device-manager στον εξυπηρετητή PulseAudio προκειμένου να μετονομάσετε συσκευές</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="232"/>
        <source>Rename device %1 to:</source>
        <translation>Μετονομασία της συσκευής %1 σε:</translation>
    </message>
    <message>
        <location filename="../../devicewidget.cc" line="239"/>
        <source>pa_ext_device_manager_set_device_description() failed</source>
        <translation>το pa_ext_device_manager_set_device_description() απέτυχε</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../../mainwindow.ui" line="14"/>
        <source>Volume Control</source>
        <translation>Έλεγχος έντασης ήχου</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="28"/>
        <source>&amp;Playback</source>
        <translation>&amp;Αναπαραγωγή</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="55"/>
        <source>&lt;i&gt;No application is currently playing audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Καμιά εφαρμογή δεν αναπαράγει ήχο αυτήν την στιγμή.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="66"/>
        <location filename="../../mainwindow.ui" line="131"/>
        <location filename="../../mainwindow.ui" line="196"/>
        <location filename="../../mainwindow.ui" line="261"/>
        <source>Show:</source>
        <translation>Εμφάνιση:</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="74"/>
        <location filename="../../mainwindow.ui" line="139"/>
        <source>All Streams</source>
        <translation>Όλες οι ροές</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="79"/>
        <location filename="../../mainwindow.ui" line="144"/>
        <source>Applications</source>
        <translation>Εφαρμογές</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="84"/>
        <location filename="../../mainwindow.ui" line="149"/>
        <source>Virtual Streams</source>
        <translation>Εικονικές ροές</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="93"/>
        <source>&amp;Recording</source>
        <translation>&amp;Ηχογράφηση</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="120"/>
        <source>&lt;i&gt;No application is currently recording audio.&lt;/i&gt;</source>
        <translation>&lt;i&gt;Καμιά εφαρμογή δεν ηχογραφεί αυτήν την στιγμή.&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="158"/>
        <source>&amp;Output Devices</source>
        <translation>Συσκευές ε&amp;ξόδου</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="185"/>
        <source>&lt;i&gt;No output devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Δεν υπάρχουν διαθέσιμες συσκευές εξόδου&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="204"/>
        <source>All Output Devices</source>
        <translation>Όλες οι συσκευές εξόδου</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="209"/>
        <source>Hardware Output Devices</source>
        <translation>Συσκευές εξόδου υλικού</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="214"/>
        <source>Virtual Output Devices</source>
        <translation>Εικονικές συσκευές εξόδου</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="223"/>
        <source>&amp;Input Devices</source>
        <translation>&amp;Συσκευές εισόδου</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="250"/>
        <source>&lt;i&gt;No input devices available&lt;/i&gt;</source>
        <translation>&lt;i&gt;Δεν υπάρχουν διαθέσιμες συσκευές εισόδου&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="269"/>
        <source>All Input Devices</source>
        <translation>Όλες οι συσκευές εισόδου</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="274"/>
        <source>All Except Monitors</source>
        <translation>Όλες εκτός των οθονών</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="279"/>
        <source>Hardware Input Devices</source>
        <translation>Συσκευές εισόδου υλικού</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="284"/>
        <source>Virtual Input Devices</source>
        <translation>Εικονικές συσκευές εισόδου</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="289"/>
        <source>Monitors</source>
        <translation>Οθόνες</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="298"/>
        <source>&amp;Configuration</source>
        <translation>&amp;Διαμόρφωση</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="325"/>
        <source>&lt;i&gt;No cards available for configuration&lt;/i&gt;</source>
        <translation>&lt;i&gt;Δεν υπάρχουν διαθέσιμες κάρτες για διαμόρφωση&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="336"/>
        <source>Show volume meters</source>
        <translation>Εμφάνιση των μετρητών έντασης</translation>
    </message>
    <message>
        <location filename="../../mainwindow.ui" line="347"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="159"/>
        <source> (plugged in)</source>
        <translation> (συνδεδεμένο)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="163"/>
        <location filename="../../mainwindow.cc" line="257"/>
        <source> (unavailable)</source>
        <translation> (μη διαθέσιμο)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="165"/>
        <location filename="../../mainwindow.cc" line="254"/>
        <source> (unplugged)</source>
        <translation> (αποσυνδεδεμένο)</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="386"/>
        <source>Failed to read data from stream</source>
        <translation>Αποτυχία ανάγνωσης δεδομένων από την ροή</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="430"/>
        <source>Peak detect</source>
        <translation>Εντοπισμός αιχμής</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="431"/>
        <source>Failed to create monitoring stream</source>
        <translation>Αποτυχία δημιουργίας της ροής εποπτείας</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="446"/>
        <source>Failed to connect monitoring stream</source>
        <translation>Αποτυχία σύνδεσης της ροής εποπτείας</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="585"/>
        <source>Ignoring sink-input due to it being designated as an event and thus handled by the Event widget</source>
        <translation>Αγνόηση του αποδέκτη εισόδου διότι είναι καθορισμένη ως ένα συμβάν και ως εκ τούτου διαχειρίζεται από το συστατικό των συμβάντων</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="757"/>
        <source>System Sounds</source>
        <translation>Ήχοι συστήματος</translation>
    </message>
    <message>
        <location filename="../../mainwindow.cc" line="1088"/>
        <source>Establishing connection to PulseAudio. Please wait...</source>
        <translation>Εδραίωση της σύνδεσης με το PulseAudio. Παρακαλώ περιμένετε...</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../../pavucontrol.cc" line="67"/>
        <source>Error</source>
        <translation>Σφάλμα</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="88"/>
        <source>Card callback failure</source>
        <translation>Αποτυχία επανάκλησης κάρτας</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="111"/>
        <source>Sink callback failure</source>
        <translation>Αποτυχία επανάκλησης αποδέκτη</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="134"/>
        <source>Source callback failure</source>
        <translation>Αποτυχία επανάκλησης πηγής</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="153"/>
        <source>Sink input callback failure</source>
        <translation>Αποτυχία επανάκλησης αποδέκτη εισόδου</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="172"/>
        <source>Source output callback failure</source>
        <translation>Αποτυχία επανάκλησης πηγής εξόδου</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="212"/>
        <source>Client callback failure</source>
        <translation>Αποτυχία επανάκλησης πελάτη</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="228"/>
        <source>Server info callback failure</source>
        <translation>Αποτυχία επανάκλησης πληροφοριών εξυπηρετητή</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="246"/>
        <location filename="../../pavucontrol.cc" line="543"/>
        <source>Failed to initialize stream_restore extension: %s</source>
        <translation>Αποτυχία αρχικοποίησης της επέκτασης επαναφοράς ροής: %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="264"/>
        <source>pa_ext_stream_restore_read() failed</source>
        <translation>το pa_ext_stream_restore_read() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="282"/>
        <location filename="../../pavucontrol.cc" line="557"/>
        <source>Failed to initialize device restore extension: %s</source>
        <translation>Αποτυχία αρχικοποίησης της επέκτασης επαναφοράς συσκευής: %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="303"/>
        <source>pa_ext_device_restore_read_sink_formats() failed</source>
        <translation>το pa_ext_device_restore_read_sink_formats() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="321"/>
        <location filename="../../pavucontrol.cc" line="570"/>
        <source>Failed to initialize device manager extension: %s</source>
        <translation>Αποτυχία αρχικοποίησης της επέκτασης διαχειριστή συσκευών: %s</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="340"/>
        <source>pa_ext_device_manager_read() failed</source>
        <translation>το pa_ext_device_manager_read() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="357"/>
        <source>pa_context_get_sink_info_by_index() failed</source>
        <translation>το pa_context_get_sink_info_by_index() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="370"/>
        <source>pa_context_get_source_info_by_index() failed</source>
        <translation>το pa_context_get_source_info_by_index() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="383"/>
        <location filename="../../pavucontrol.cc" line="396"/>
        <source>pa_context_get_sink_input_info() failed</source>
        <translation>το pa_context_get_sink_input_info() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="409"/>
        <source>pa_context_get_client_info() failed</source>
        <translation>το pa_context_get_client_info() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="419"/>
        <location filename="../../pavucontrol.cc" line="484"/>
        <source>pa_context_get_server_info() failed</source>
        <translation>το pa_context_get_server_info() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="432"/>
        <source>pa_context_get_card_info_by_index() failed</source>
        <translation>το pa_context_get_card_info_by_index() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="475"/>
        <source>pa_context_subscribe() failed</source>
        <translation>το pa_context_subscribe() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="491"/>
        <source>pa_context_client_info_list() failed</source>
        <translation>το pa_context_client_info_list() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="498"/>
        <source>pa_context_get_card_info_list() failed</source>
        <translation>το pa_context_get_card_info_list() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="505"/>
        <source>pa_context_get_sink_info_list() failed</source>
        <translation>το pa_context_get_sink_info_list() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="512"/>
        <source>pa_context_get_source_info_list() failed</source>
        <translation>το pa_context_get_source_info_list() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="519"/>
        <source>pa_context_get_sink_input_info_list() failed</source>
        <translation>το pa_context_get_sink_input_info_list() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="526"/>
        <source>pa_context_get_source_output_info_list() failed</source>
        <translation>το pa_context_get_source_output_info_list() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="585"/>
        <location filename="../../pavucontrol.cc" line="636"/>
        <source>Connection failed, attempting reconnect</source>
        <translation>Αποτυχία της σύνδεσης, προσπάθεια επανασύνδεσης</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="608"/>
        <location filename="../../pavucontrol.cc" line="668"/>
        <source>PulseAudio Volume Control</source>
        <translation>Έλεγχος έντασης ήχου PulseAudio</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="623"/>
        <source>Connection to PulseAudio failed. Automatic retry in 5s

In this case this is likely because PULSE_SERVER in the Environment/X11 Root Window Properties
or default-server in client.conf is misconfigured.
This situation can also arrise when PulseAudio crashed and left stale details in the X11 Root Window.
If this is the case, then PulseAudio should autospawn again, or if this is not configured you should
run start-pulseaudio-x11 manually.</source>
        <translation>Η σύνδεση στο PulseAudio απέτυχε. Αυτόματη επανάληψη σε 5 δευτ.

Αυτό μπορεί να συμβαίνει διότι ο PULSE_SERVER είναι κακώς διαμορφωμένος στο παράθυρο διαχειριστή Ιδιότητες Environment/X11
ή το default-server στο client.conf.
Αυτή η κατάσταση συναντάται επίσης μετά από κατάρρευση του PulseAudio και παραμονή υπολειμμάτων στο παράθυρο διαχειριστή X11.
Αν πρόκειται για αυτήν την περίπτωση, τότε το PulseAudio θα πρέπει να αυτοδημιουργηθεί εκ νέου, ή αν αυτό δεν έχει ρυθμιστεί θα πρέπει να εκτελέσετε χειροκίνητα το start-pulseaudio-x11.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="676"/>
        <source>Select a specific tab on load.</source>
        <translation>Επιλογή μιας συγκεκριμένης καρτέλας κατά την φόρτωση.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="679"/>
        <source>Retry forever if pa quits (every 5 seconds).</source>
        <translation>Επαναφορά αέναα κατά την εγκατάλειψη του pa (κάθε 5 δευτερόλεπτα).</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="682"/>
        <source>Maximize the window.</source>
        <translation>Μεγιστοποίηση του παράθυρου.</translation>
    </message>
    <message>
        <location filename="../../pavucontrol.cc" line="707"/>
        <source>Fatal Error: Unable to connect to PulseAudio</source>
        <translation>Ανεπανόρθωτο σφάλμα: Αδύνατη η σύνδεση στο PulseAudio</translation>
    </message>
</context>
<context>
    <name>RoleWidget</name>
    <message>
        <location filename="../../rolewidget.cc" line="59"/>
        <source>pa_ext_stream_restore_write() failed</source>
        <translation>το pa_ext_stream_restore_write() απέτυχε</translation>
    </message>
</context>
<context>
    <name>SinkInputWidget</name>
    <message>
        <location filename="../../sinkinputwidget.cc" line="36"/>
        <source>on</source>
        <translation>σε</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="39"/>
        <source>Terminate Playback</source>
        <translation>Τερματισμός αναπαραγωγής</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="53"/>
        <source>Unknown output</source>
        <translation>Άγνωστη έξοδος</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="64"/>
        <source>pa_context_set_sink_input_volume() failed</source>
        <translation>το pa_context_set_sink_input_volume() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="79"/>
        <source>pa_context_set_sink_input_mute() failed</source>
        <translation>το pa_context_set_sink_input_mute() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="89"/>
        <source>pa_context_kill_sink_input() failed</source>
        <translation>το pa_context_kill_sink_input() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sinkinputwidget.cc" line="114"/>
        <source>pa_context_move_sink_input_by_index() failed</source>
        <translation>το pa_context_move_sink_input_by_index() απέτυχε</translation>
    </message>
</context>
<context>
    <name>SinkWidget</name>
    <message>
        <location filename="../../sinkwidget.cc" line="81"/>
        <source>pa_context_set_sink_volume_by_index() failed</source>
        <translation>το pa_context_set_sink_volume_by_index() απέτυχε</translation>
    </message>
    <message>
        <source>Volume Control Feedback Sound</source>
        <translation type="vanished">Έλεγχος έντασης ήχου</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="96"/>
        <source>pa_context_set_sink_mute_by_index() failed</source>
        <translation>το pa_context_set_sink_mute_by_index() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="110"/>
        <source>pa_context_set_default_sink() failed</source>
        <translation>το pa_context_set_default_sink() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="126"/>
        <source>pa_context_set_sink_port_by_index() failed</source>
        <translation>το pa_context_set_sink_port_by_index() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sinkwidget.cc" line="166"/>
        <source>pa_ext_device_restore_save_sink_formats() failed</source>
        <translation>το pa_ext_device_restore_save_sink_formats() απέτυχε</translation>
    </message>
</context>
<context>
    <name>SourceOutputWidget</name>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="36"/>
        <source>from</source>
        <translation>από</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="39"/>
        <source>Terminate Recording</source>
        <translation>Τερματισμός ηχογράφησης</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="60"/>
        <source>Unknown input</source>
        <translation>Άγνωστη είσοδος</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="72"/>
        <source>pa_context_set_source_output_volume() failed</source>
        <translation>το pa_context_set_source_output_volume() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="87"/>
        <source>pa_context_set_source_output_mute() failed</source>
        <translation>το pa_context_set_source_output_mute() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="98"/>
        <source>pa_context_kill_source_output() failed</source>
        <translation>το pa_context_kill_source_output() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sourceoutputwidget.cc" line="125"/>
        <source>pa_context_move_source_output_by_index() failed</source>
        <translation>το pa_context_move_source_output_by_index() απέτυχε</translation>
    </message>
</context>
<context>
    <name>SourceWidget</name>
    <message>
        <location filename="../../sourcewidget.cc" line="35"/>
        <source>pa_context_set_source_volume_by_index() failed</source>
        <translation>το pa_context_set_source_volume_by_index() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="50"/>
        <source>pa_context_set_source_mute_by_index() failed</source>
        <translation>το pa_context_set_source_mute_by_index() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="64"/>
        <source>pa_context_set_default_source() failed</source>
        <translation>το pa_context_set_default_source() απέτυχε</translation>
    </message>
    <message>
        <location filename="../../sourcewidget.cc" line="80"/>
        <source>pa_context_set_source_port_by_index() failed</source>
        <translation>το pa_context_set_source_port_by_index() απέτυχε</translation>
    </message>
</context>
<context>
    <name>StreamWidget</name>
    <message>
        <location filename="../../streamwidget.ui" line="14"/>
        <source>Form</source>
        <translation>Φόρμα</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="32"/>
        <source>Device Title</source>
        <translation>Τίτλος συσκευής</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="52"/>
        <source>direction</source>
        <translation>κατεύθυνση</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="59"/>
        <source>device</source>
        <translation>συσκευή</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="66"/>
        <source>Mute audio</source>
        <translation>Σίγαση ήχου</translation>
    </message>
    <message>
        <location filename="../../streamwidget.ui" line="79"/>
        <source>Lock channels together</source>
        <translation>Κλείδωμα των καναλιών μαζί</translation>
    </message>
    <message>
        <source>Device</source>
        <translation type="vanished">Συσκευές _εισόδου</translation>
    </message>
    <message>
        <location filename="../../streamwidget.cc" line="34"/>
        <source>Terminate</source>
        <translation>Τερματισμός</translation>
    </message>
</context>
</TS>
